jdk/test/sun/net/www/AuthHeaderTest.java
changeset 13788 3f38e525f30a
parent 5506 202f599c92aa
child 14342 8435a30053c1
--- a/jdk/test/sun/net/www/AuthHeaderTest.java	Fri Sep 07 14:00:31 2012 +0100
+++ b/jdk/test/sun/net/www/AuthHeaderTest.java	Fri Sep 07 15:30:17 2012 +0100
@@ -25,7 +25,7 @@
  * @test
  * @bug 4804309
  * @library ../../../sun/net/www/httptest/
  * @build HttpCallback HttpServer ClosedChannelList HttpTransaction
  * @run main AuthHeaderTest
  * @summary AuthHeaderTest bug
  */
@@ -90,13 +90,13 @@
         is.close();
     }
 
-    static HttpServer server;
+    static TestHttpServer server;
 
     public static void main (String[] args) throws Exception {
         MyAuthenticator auth = new MyAuthenticator ();
         Authenticator.setDefault (auth);
         try {
-            server = new HttpServer (new AuthHeaderTest(), 1, 10, 0);
+            server = new TestHttpServer (new AuthHeaderTest(), 1, 10, 0);
             System.out.println ("Server: listening on port: " + server.getLocalPort());
             client ("http://localhost:"+server.getLocalPort()+"/d1/foo.html");
         } catch (Exception e) {
@@ -25,7 +25,7 @@
  * @bug 4804309
  * @library ../../../sun/net/www/httptest/
- * @build HttpCallback HttpServer ClosedChannelList HttpTransaction
+ * @build HttpCallback TestHttpServer ClosedChannelList HttpTransaction
  * @run main AuthHeaderTest
  * @summary AuthHeaderTest bug